Author: hbelusca
Date: Mon Feb 29 01:22:02 2016
New Revision: 70815
URL:
http://svn.reactos.org/svn/reactos?rev=70815&view=rev
Log:
[REACTOS]: s/partiton/partition/
Modified:
trunk/reactos/base/setup/usetup/cmdcons.c
trunk/reactos/base/setup/usetup/interface/usetup.c
trunk/reactos/base/setup/usetup/lang/bg-BG.h
trunk/reactos/base/setup/usetup/lang/bn-BD.h
trunk/reactos/base/setup/usetup/lang/cs-CZ.h
trunk/reactos/base/setup/usetup/lang/de-DE.h
trunk/reactos/base/setup/usetup/lang/el-GR.h
trunk/reactos/base/setup/usetup/lang/en-US.h
trunk/reactos/base/setup/usetup/lang/et-EE.h
trunk/reactos/base/setup/usetup/lang/he-IL.h
trunk/reactos/base/setup/usetup/lang/it-IT.h
trunk/reactos/base/setup/usetup/lang/ja-JP.h
trunk/reactos/base/setup/usetup/lang/lt-LT.h
trunk/reactos/base/setup/usetup/lang/nl-NL.h
trunk/reactos/base/setup/usetup/lang/pl-PL.h
trunk/reactos/base/setup/usetup/lang/pt-BR.h
trunk/reactos/base/setup/usetup/lang/ru-RU.h
trunk/reactos/base/setup/usetup/lang/sk-SK.h
trunk/reactos/base/setup/usetup/lang/sq-AL.h
trunk/reactos/base/setup/usetup/lang/sv-SE.h
trunk/reactos/base/setup/usetup/lang/uk-UA.h
trunk/reactos/base/setup/usetup/partlist.c
trunk/reactos/base/system/diskpart/partlist.c
trunk/reactos/drivers/storage/class/disk/disk.c
trunk/reactos/lib/fslib/vfatlib/vfatlib.c
Modified: trunk/reactos/base/setup/usetup/cmdcons.c
URL:
http://svn.reactos.org/svn/reactos/trunk/reactos/base/setup/usetup/cmdcons.…
==============================================================================
--- trunk/reactos/base/setup/usetup/cmdcons.c [iso-8859-1] (original)
+++ trunk/reactos/base/setup/usetup/cmdcons.c [iso-8859-1] Mon Feb 29 01:22:02 2016
@@ -556,7 +556,7 @@
VOID
HelpPartInfo(VOID)
{
- CONSOLE_ConOutPrintf("PARTINFO DiskNumber\n\nDumps a partiton table to the
screen.\n\n");
+ CONSOLE_ConOutPrintf("PARTINFO DiskNumber\n\nDumps a partition table to the
screen.\n\n");
}
Modified: trunk/reactos/base/setup/usetup/interface/usetup.c
URL:
http://svn.reactos.org/svn/reactos/trunk/reactos/base/setup/usetup/interfac…
==============================================================================
--- trunk/reactos/base/setup/usetup/interface/usetup.c [iso-8859-1] (original)
+++ trunk/reactos/base/setup/usetup/interface/usetup.c [iso-8859-1] Mon Feb 29 01:22:02
2016
@@ -2919,7 +2919,7 @@
if (PartEntry->SectorCount.QuadPart < 65536)
{
- /* FAT16 CHS partition (partiton size < 32MB) */
+ /* FAT16 CHS partition (partition size < 32MB) */
PartEntry->PartitionType = PARTITION_FAT_16;
}
else if (PartEntry->SectorCount.QuadPart < 1048576)
Modified: trunk/reactos/base/setup/usetup/lang/bg-BG.h
URL:
http://svn.reactos.org/svn/reactos/trunk/reactos/base/setup/usetup/lang/bg-…
==============================================================================
--- trunk/reactos/base/setup/usetup/lang/bg-BG.h [iso-8859-1] (original)
+++ trunk/reactos/base/setup/usetup/lang/bg-BG.h [iso-8859-1] Mon Feb 29 01:22:02 2016
@@ -876,7 +876,7 @@
{
6,
15,
- "programs on the partiton, or when you are sure you want to delete
them.",
+ "programs on the partition, or when you are sure you want to delete
them.",
TEXT_STYLE_NORMAL
},
{
Modified: trunk/reactos/base/setup/usetup/lang/bn-BD.h
URL:
http://svn.reactos.org/svn/reactos/trunk/reactos/base/setup/usetup/lang/bn-…
==============================================================================
--- trunk/reactos/base/setup/usetup/lang/bn-BD.h [iso-8859-1] (original)
+++ trunk/reactos/base/setup/usetup/lang/bn-BD.h [iso-8859-1] Mon Feb 29 01:22:02 2016
@@ -866,7 +866,7 @@
{
6,
15,
- "programs on the partiton, or when you are sure you want to delete
them.",
+ "programs on the partition, or when you are sure you want to delete
them.",
TEXT_STYLE_NORMAL
},
{
Modified: trunk/reactos/base/setup/usetup/lang/cs-CZ.h
URL:
http://svn.reactos.org/svn/reactos/trunk/reactos/base/setup/usetup/lang/cs-…
==============================================================================
--- trunk/reactos/base/setup/usetup/lang/cs-CZ.h [iso-8859-1] (original)
+++ trunk/reactos/base/setup/usetup/lang/cs-CZ.h [iso-8859-1] Mon Feb 29 01:22:02 2016
@@ -874,7 +874,7 @@
{
6,
15,
- "programs on the partiton, or when you are sure you want to delete
them.",
+ "programs on the partition, or when you are sure you want to delete
them.",
TEXT_STYLE_NORMAL
},
{
Modified: trunk/reactos/base/setup/usetup/lang/de-DE.h
URL:
http://svn.reactos.org/svn/reactos/trunk/reactos/base/setup/usetup/lang/de-…
==============================================================================
--- trunk/reactos/base/setup/usetup/lang/de-DE.h [iso-8859-1] (original)
+++ trunk/reactos/base/setup/usetup/lang/de-DE.h [iso-8859-1] Mon Feb 29 01:22:02 2016
@@ -861,7 +861,7 @@
{
6,
15,
- "programs on the partiton, or when you are sure you want to delete
them.",
+ "programs on the partition, or when you are sure you want to delete
them.",
TEXT_STYLE_NORMAL
},
{
Modified: trunk/reactos/base/setup/usetup/lang/el-GR.h
URL:
http://svn.reactos.org/svn/reactos/trunk/reactos/base/setup/usetup/lang/el-…
==============================================================================
--- trunk/reactos/base/setup/usetup/lang/el-GR.h [iso-8859-1] (original)
+++ trunk/reactos/base/setup/usetup/lang/el-GR.h [iso-8859-1] Mon Feb 29 01:22:02 2016
@@ -879,7 +879,7 @@
{
6,
15,
- "programs on the partiton, or when you are sure you want to delete
them.",
+ "programs on the partition, or when you are sure you want to delete
them.",
TEXT_STYLE_NORMAL
},
{
@@ -1454,7 +1454,7 @@
" ¡«á©«© ¨ã¡ æ« «¦¬¢á® ©«¦¤ ⤪ ©¡¢¨æª å©¡¦ª §¨ ⮠⤠£
©¬£«æ\n"
"partition table §¦¬ £§¦¨å ¤ ¢®å ©à©«á!\n"
"\n"
- " £ ¦¬¨å ã ¨ã partitions £§¦¨å ¤ ¡«©«¨â¯ «¦ partiton
table.\n"
+ " £ ¦¬¨å ã ¨ã partitions £§¦¨å ¤ ¡«©«¨â¯ «¦ partition
table.\n"
"\n"
" \x07 «ã©« F3 ¤ §¦®à¨ã©« §æ «¤ ¡«á©«©.\n"
" \x07 «ã©« ENTER ¤ ©¬¤®å©«.",
Modified: trunk/reactos/base/setup/usetup/lang/en-US.h
URL:
http://svn.reactos.org/svn/reactos/trunk/reactos/base/setup/usetup/lang/en-…
==============================================================================
--- trunk/reactos/base/setup/usetup/lang/en-US.h [iso-8859-1] (original)
+++ trunk/reactos/base/setup/usetup/lang/en-US.h [iso-8859-1] Mon Feb 29 01:22:02 2016
@@ -865,7 +865,7 @@
{
6,
15,
- "programs on the partiton, or when you are sure you want to delete
them.",
+ "programs on the partition, or when you are sure you want to delete
them.",
TEXT_STYLE_NORMAL
},
{
Modified: trunk/reactos/base/setup/usetup/lang/et-EE.h
URL:
http://svn.reactos.org/svn/reactos/trunk/reactos/base/setup/usetup/lang/et-…
==============================================================================
--- trunk/reactos/base/setup/usetup/lang/et-EE.h [iso-8859-1] (original)
+++ trunk/reactos/base/setup/usetup/lang/et-EE.h [iso-8859-1] Mon Feb 29 01:22:02 2016
@@ -867,7 +867,7 @@
{
6,
15,
- "programs on the partiton, or when you are sure you want to delete
them.",
+ "programs on the partition, or when you are sure you want to delete
them.",
TEXT_STYLE_NORMAL
},
{
Modified: trunk/reactos/base/setup/usetup/lang/he-IL.h
URL:
http://svn.reactos.org/svn/reactos/trunk/reactos/base/setup/usetup/lang/he-…
==============================================================================
--- trunk/reactos/base/setup/usetup/lang/he-IL.h [iso-8859-1] (original)
+++ trunk/reactos/base/setup/usetup/lang/he-IL.h [iso-8859-1] Mon Feb 29 01:22:02 2016
@@ -867,7 +867,7 @@
{
6,
15,
- "programs on the partiton, or when you are sure you want to delete
them.",
+ "programs on the partition, or when you are sure you want to delete
them.",
TEXT_STYLE_NORMAL
},
{
Modified: trunk/reactos/base/setup/usetup/lang/it-IT.h
URL:
http://svn.reactos.org/svn/reactos/trunk/reactos/base/setup/usetup/lang/it-…
==============================================================================
--- trunk/reactos/base/setup/usetup/lang/it-IT.h [iso-8859-1] (original)
+++ trunk/reactos/base/setup/usetup/lang/it-IT.h [iso-8859-1] Mon Feb 29 01:22:02 2016
@@ -874,7 +874,7 @@
{
6,
15,
- "programs on the partiton, or when you are sure you want to delete
them.",
+ "programs on the partition, or when you are sure you want to delete
them.",
TEXT_STYLE_NORMAL
},
{
Modified: trunk/reactos/base/setup/usetup/lang/ja-JP.h
URL:
http://svn.reactos.org/svn/reactos/trunk/reactos/base/setup/usetup/lang/ja-…
==============================================================================
--- trunk/reactos/base/setup/usetup/lang/ja-JP.h [iso-8859-1] (original)
+++ trunk/reactos/base/setup/usetup/lang/ja-JP.h [iso-8859-1] Mon Feb 29 01:22:02 2016
@@ -868,7 +868,7 @@
{
6,
15,
- "programs on the partiton, or when you are sure you want to delete
them.",
+ "programs on the partition, or when you are sure you want to delete
them.",
TEXT_STYLE_NORMAL
},
{
Modified: trunk/reactos/base/setup/usetup/lang/lt-LT.h
URL:
http://svn.reactos.org/svn/reactos/trunk/reactos/base/setup/usetup/lang/lt-…
==============================================================================
--- trunk/reactos/base/setup/usetup/lang/lt-LT.h [iso-8859-1] (original)
+++ trunk/reactos/base/setup/usetup/lang/lt-LT.h [iso-8859-1] Mon Feb 29 01:22:02 2016
@@ -876,7 +876,7 @@
{
6,
15,
- "programs on the partiton, or when you are sure you want to delete
them.",
+ "programs on the partition, or when you are sure you want to delete
them.",
TEXT_STYLE_NORMAL
},
{
Modified: trunk/reactos/base/setup/usetup/lang/nl-NL.h
URL:
http://svn.reactos.org/svn/reactos/trunk/reactos/base/setup/usetup/lang/nl-…
==============================================================================
--- trunk/reactos/base/setup/usetup/lang/nl-NL.h [iso-8859-1] (original)
+++ trunk/reactos/base/setup/usetup/lang/nl-NL.h [iso-8859-1] Mon Feb 29 01:22:02 2016
@@ -896,7 +896,7 @@
{
6,
15,
- "programs on the partiton, or when you are sure you want to delete
them.",
+ "programs on the partition, or when you are sure you want to delete
them.",
TEXT_STYLE_NORMAL
},
{
Modified: trunk/reactos/base/setup/usetup/lang/pl-PL.h
URL:
http://svn.reactos.org/svn/reactos/trunk/reactos/base/setup/usetup/lang/pl-…
==============================================================================
--- trunk/reactos/base/setup/usetup/lang/pl-PL.h [iso-8859-1] (original)
+++ trunk/reactos/base/setup/usetup/lang/pl-PL.h [iso-8859-1] Mon Feb 29 01:22:02 2016
@@ -877,7 +877,7 @@
{
6,
15,
- "programs on the partiton, or when you are sure you want to delete
them.",
+ "programs on the partition, or when you are sure you want to delete
them.",
TEXT_STYLE_NORMAL
},
{
Modified: trunk/reactos/base/setup/usetup/lang/pt-BR.h
URL:
http://svn.reactos.org/svn/reactos/trunk/reactos/base/setup/usetup/lang/pt-…
==============================================================================
--- trunk/reactos/base/setup/usetup/lang/pt-BR.h [iso-8859-1] (original)
+++ trunk/reactos/base/setup/usetup/lang/pt-BR.h [iso-8859-1] Mon Feb 29 01:22:02 2016
@@ -886,7 +886,7 @@
{
6,
15,
- "programs on the partiton, or when you are sure you want to delete
them.",
+ "programs on the partition, or when you are sure you want to delete
them.",
TEXT_STYLE_NORMAL
},
{
Modified: trunk/reactos/base/setup/usetup/lang/ru-RU.h
URL:
http://svn.reactos.org/svn/reactos/trunk/reactos/base/setup/usetup/lang/ru-…
==============================================================================
--- trunk/reactos/base/setup/usetup/lang/ru-RU.h [iso-8859-1] (original)
+++ trunk/reactos/base/setup/usetup/lang/ru-RU.h [iso-8859-1] Mon Feb 29 01:22:02 2016
@@ -867,7 +867,7 @@
{
6,
15,
- "programs on the partiton, or when you are sure you want to delete
them.",
+ "programs on the partition, or when you are sure you want to delete
them.",
TEXT_STYLE_NORMAL
},
{
Modified: trunk/reactos/base/setup/usetup/lang/sk-SK.h
URL:
http://svn.reactos.org/svn/reactos/trunk/reactos/base/setup/usetup/lang/sk-…
==============================================================================
--- trunk/reactos/base/setup/usetup/lang/sk-SK.h [iso-8859-1] (original)
+++ trunk/reactos/base/setup/usetup/lang/sk-SK.h [iso-8859-1] Mon Feb 29 01:22:02 2016
@@ -875,7 +875,7 @@
{
6,
15,
- "programs on the partiton, or when you are sure you want to delete
them.",
+ "programs on the partition, or when you are sure you want to delete
them.",
TEXT_STYLE_NORMAL
},
{
Modified: trunk/reactos/base/setup/usetup/lang/sq-AL.h
URL:
http://svn.reactos.org/svn/reactos/trunk/reactos/base/setup/usetup/lang/sq-…
==============================================================================
--- trunk/reactos/base/setup/usetup/lang/sq-AL.h [iso-8859-1] (original)
+++ trunk/reactos/base/setup/usetup/lang/sq-AL.h [iso-8859-1] Mon Feb 29 01:22:02 2016
@@ -871,7 +871,7 @@
{
6,
15,
- "programs on the partiton, or when you are sure you want to delete
them.",
+ "programs on the partition, or when you are sure you want to delete
them.",
TEXT_STYLE_NORMAL
},
{
Modified: trunk/reactos/base/setup/usetup/lang/sv-SE.h
URL:
http://svn.reactos.org/svn/reactos/trunk/reactos/base/setup/usetup/lang/sv-…
==============================================================================
--- trunk/reactos/base/setup/usetup/lang/uk-UA.h [iso-8859-1] (original)
+++ trunk/reactos/base/setup/usetup/lang/uk-UA.h [iso-8859-1] Mon Feb 29 01:22:02 2016
@@ -873,7 +873,7 @@
{
6,
15,
- "programs on the partiton, or when you are sure you want to delete
them.",
+ "programs on the partition, or when you are sure you want to delete
them.",
TEXT_STYLE_NORMAL
},
{
Modified: trunk/reactos/base/setup/usetup/partlist.c
URL:
http://svn.reactos.org/svn/reactos/trunk/reactos/base/setup/usetup/partlist…
==============================================================================
--- trunk/reactos/base/system/diskpart/partlist.c [iso-8859-1] (original)
+++ trunk/reactos/base/system/diskpart/partlist.c [iso-8859-1] Mon Feb 29 01:22:02 2016
@@ -1015,12 +1015,12 @@
}
else
{
- DPRINT1("No matching aligment found! Partiton 1 starts at %I64u\n",
DiskEntry->LayoutBuffer->PartitionEntry[0].StartingOffset.QuadPart);
+ DPRINT1("No matching aligment found! Partition 1 starts at
%I64u\n", DiskEntry->LayoutBuffer->PartitionEntry[0].StartingOffset.QuadPart);
}
}
else
{
- DPRINT1("No valid partiton table found! Use megabyte (%lu Sectors)
alignment!\n", (1024 * 1024) / DiskEntry->BytesPerSector);
+ DPRINT1("No valid partition table found! Use megabyte (%lu Sectors)
alignment!\n", (1024 * 1024) / DiskEntry->BytesPerSector);
}
Modified: trunk/reactos/drivers/storage/class/disk/disk.c
URL:
http://svn.reactos.org/svn/reactos/trunk/reactos/drivers/storage/class/disk…
==============================================================================
--- trunk/reactos/drivers/storage/class/disk/disk.c [iso-8859-1] (original)
+++ trunk/reactos/drivers/storage/class/disk/disk.c [iso-8859-1] Mon Feb 29 01:22:02 2016
@@ -2524,7 +2524,7 @@
partitionEntry = &partitionList->PartitionEntry[i];
//
- // Check if empty, or describes extended partiton or hasn't
changed.
+ // Check if empty, or describes extended partition or hasn't
changed.
//
if (partitionEntry->PartitionType == PARTITION_ENTRY_UNUSED ||
@@ -4885,7 +4885,7 @@
partitionEntry = &partitionList->PartitionEntry[partition];
//
- // Check if empty, or describes extended partiton or hasn't changed.
+ // Check if empty, or describes extended partition or hasn't changed.
//
if (partitionEntry->PartitionType == PARTITION_ENTRY_UNUSED ||
@@ -4995,7 +4995,7 @@
partitionEntry = &partitionList->PartitionEntry[partition];
//
- // Check if empty, or describes an extended partiton.
+ // Check if empty, or describes an extended partition.
//
if (partitionEntry->PartitionType == PARTITION_ENTRY_UNUSED ||
Modified: trunk/reactos/lib/fslib/vfatlib/vfatlib.c
URL:
http://svn.reactos.org/svn/reactos/trunk/reactos/lib/fslib/vfatlib/vfatlib.…
==============================================================================
--- trunk/reactos/lib/fslib/vfatlib/vfatlib.c [iso-8859-1] (original)
+++ trunk/reactos/lib/fslib/vfatlib/vfatlib.c [iso-8859-1] Mon Feb 29 01:22:02 2016
@@ -147,7 +147,7 @@
if (PartitionInfo.PartitionLength.QuadPart < (32LL * 1024LL * 1024LL))
{
- /* FAT16 CHS partition (partiton size < 32MB) */
+ /* FAT16 CHS partition (partition size < 32MB) */
PartitionInfo.PartitionType = PARTITION_FAT_16;
}
else if (PartitionInfo.PartitionLength.QuadPart < (512LL * 1024LL *
1024LL))
--- trunk/reactos/base/setup/usetup/lang/sv-SE.h [iso-8859-1] (original)
+++ trunk/reactos/base/setup/usetup/lang/sv-SE.h [iso-8859-1] Mon Feb 29 01:22:02 2016
@@ -874,7 +874,7 @@
{
6,
15,
- "programs on the partiton, or when you are sure you want to delete
them.",
+ "programs on the partition, or when you are sure you want to delete
them.",
TEXT_STYLE_NORMAL
},
{
@@ -1732,7 +1732,7 @@
"Storlek p den nya partitionen:"},
{STRING_CHOOSENEWPARTITION,
"You have chosen to create a primary partition on"},
// "Du har valt att skapa en ny partiton p"},
{STRING_CHOOSE_NEW_EXTENDED_PARTITION,
"You have chosen to create an extended partition on"},
{STRING_CHOOSE_NEW_LOGICAL_PARTITION,
@@ -1732,7 +1732,7 @@
{STRING_CHOOSENEWPARTITION,
"You have chosen to create a primary partition on"},
-// "Du har valt att skapa en ny partiton p"},
+// "Du har valt att skapa en ny partition p"},
{STRING_CHOOSE_NEW_EXTENDED_PARTITION,
"You have chosen to create an extended partition on"},
Modified: trunk/reactos/base/setup/usetup/lang/uk-UA.h
URL:
http://svn.reactos.org/svn/reactos/trunk/reactos/base/setup/usetup/lang/uk-…
==============================================================================
--- trunk/reactos/base/setup/usetup/partlist.c [iso-8859-1] (original)
+++ trunk/reactos/base/setup/usetup/partlist.c [iso-8859-1] Mon Feb 29 01:22:02 2016
@@ -42,7 +42,7 @@
} PARTITION_TYPE, *PPARTITION_TYPE;
/*
* This partiton type list was ripped off the kernelDisk.c module from:
*
* Visopsys Operating System
* Copyright (C) 1998-2015 J. Andrew McLaughlin
@@ -1362,12 +1362,12 @@
}
else
{
- DPRINT1("No matching aligment found! Partiton 1 starts at %I64u\n",
DiskEntry->LayoutBuffer->PartitionEntry[0].StartingOffset.QuadPart);
+ DPRINT1("No matching aligment found! Partition 1 starts at
%I64u\n", DiskEntry->LayoutBuffer->PartitionEntry[0].StartingOffset.QuadPart);
}
}
else
{
- DPRINT1("No valid partiton table found! Use megabyte (%lu Sectors)
alignment!\n", (1024 * 1024) / DiskEntry->BytesPerSector);
+ DPRINT1("No valid partition table found! Use megabyte (%lu Sectors)
alignment!\n", (1024 * 1024) / DiskEntry->BytesPerSector);
}
@@ -3036,7 +3036,7 @@
DiskEntry = List->CurrentDisk;
PartEntry = List->CurrentPartition;
- /* Delete all logical partiton entries if an extended partition will be deleted */
+ /* Delete all logical partition entries if an extended partition will be deleted */
if (DiskEntry->ExtendedPartition == PartEntry)
{
while (!IsListEmpty(&DiskEntry->LogicalPartListHead))
@@ -42,7 +42,7 @@
} PARTITION_TYPE, *PPARTITION_TYPE;
/*
- * This partiton type list was ripped off the kernelDisk.c module from:
+ * This partition type list was ripped off the kernelDisk.c module from:
*
* Visopsys Operating System
Modified: trunk/reactos/base/system/diskpart/partlist.c
URL:
http://svn.reactos.org/svn/reactos/trunk/reactos/base/system/diskpart/partl…
==============================================================================